package com.fs.his.service;

import java.util.List;
import com.fs.his.domain.FsInquiryTemp;
import com.fs.his.param.FsInquiryTempParam;
import com.fs.his.vo.FsInquiryTempListVO;

/**
 * 模板Service接口
 *
 * @author fs
 * @date 2023-09-04
 */
public interface IFsInquiryTempService
{
    /**
     * 查询模板
     *
     * @param tempId 模板主键
     * @return 模板
     */
    public FsInquiryTemp selectFsInquiryTempByTempId(Long tempId);

    /**
     * 查询模板列表
     *
     * @param fsInquiryTemp 模板
     * @return 模板集合
     */
    public List<FsInquiryTemp> selectFsInquiryTempList(FsInquiryTemp fsInquiryTemp);

    /**
     * 新增模板
     *
     * @param fsInquiryTemp 模板
     * @return 结果
     */
    public int insertFsInquiryTemp(FsInquiryTemp fsInquiryTemp);

    /**
     * 修改模板
     *
     * @param fsInquiryTemp 模板
     * @return 结果
     */
    public int updateFsInquiryTemp(FsInquiryTemp fsInquiryTemp);

    /**
     * 批量删除模板
     *
     * @param tempIds 需要删除的模板主键集合
     * @return 结果
     */
    public int deleteFsInquiryTempByTempIds(Long[] tempIds);

    /**
     * 删除模板信息
     *
     * @param tempId 模板主键
     * @return 结果
     */
    public int deleteFsInquiryTempByTempId(Long tempId);

    List<FsInquiryTempListVO> selectFsInquiryTempListVO(FsInquiryTempParam fsInquiryTemp);
}
